import { Nsci } from "../standard/index.js";
export declare type ExternalRuntimeConfiguration = {
    directory: string;
    strategy: Nsci.InputStrategy;
    vulnerabilities: Nsci.Severity;
    warnings: Nsci.Warnings;
    reporters: string | Nsci.ReporterTarget[];
};
/**
 * In order to unify all types of external configurations (NodeSecure runtime
 * config, API config, CLI config), we must provide a standard
 * ExternalRuntimeConfiguration type which can be then sanitized, validated and
 * adapted to the standard @nodesecure/ci runtime config format.
 *
 * Consequently each external config must implement an ExternalConfigAdapter
 * which converts any type of config to the ExternalRuntimeConfiguration type.
 * This ExternalRuntimeConfiguration type can then be transparently sanitized,
 * validated without too many edge cases.
 */
export declare type ExternalConfigAdapter<T> = {
    adaptToExternalConfig: (config: T) => ExternalRuntimeConfiguration;
};
export declare const defaultExternalConfigOptions: ExternalRuntimeConfiguration;
